mysql.exceptions.internal.Connected_Error

Package mysql :: Package exceptions :: Module internal :: Class Connected_Error |
[hide private]
[frames] | no frames]

# Class Connected_Error

source code

    exceptions.Exception --+
                           |
                  base.Error --+
                               |
                              Connected_Error

Attempted to use a command that cannot be used while connected.

Instance Methods | [hide private]
Inherited from `exceptions.Exception`: `__getitem__`, `__init__`, `__str__`